@@ -45,8 +45,6 @@ QFileSystemWatcher * watcher;
 int multi = 1;
 int ordenFile;
 QString color1, color2;
-QMenu *contextMenu;
-
 
 
 MainWindow::MainWindow(QWidget *parent, QString openfolder) :
@@ -613,15 +611,13 @@ void MainWindow::on_listWidget_itemClicked(QListWidgetItem* item)
         {
             OpenFile( temp );
         }
-
-        if ( QFileInfo(temp).isDir() )
+        else if ( QFileInfo(temp).isDir() )
         {
             CargarBrowser( temp );
         }
     }
     else
     {
-
         if ( ui->listWidget->currentItem()->checkState()==Qt::Checked) {
             ui->listWidget->currentItem()->setCheckState(Qt::Unchecked);
             ui->listWidget->currentItem()->setData(Qt::UserRole+3, 0);
@@ -644,8 +640,7 @@ void MainWindow::on_listWidget_itemDoubleClicked(QListWidgetItem* item)
         {
             OpenFile( temp );
         }
-
-        if ( QFileInfo(temp).isDir() )
+        else if ( QFileInfo(temp).isDir() )
         {
             QApplication::processEvents();
             CargarBrowser( temp );
@@ -755,7 +750,54 @@ void MainWindow::on_listWidget_customContextMenuRequested(QPoint pos)
     if ( ui->listWidget->count() == 0 ) return;
     if ( ui->listWidget->selectedItems().count() == 0 ) return;
 
+    int seleccionados=0;
+    QString item = sPath + "/" + ui->listWidget->currentItem()->statusTip();
+
+    if ( multi == 1 )
+    {
+        for (int mi=0; mi < ui->listWidget->count(); ++mi)
+        {
+            if ( ui->listWidget->item(mi)->checkState()==Qt::Checked ) seleccionados=seleccionados+1;
+        }
+        if (seleccionados==0) return;
+        if (seleccionados>=1 && ui->listWidget->currentItem()->checkState()==Qt::Unchecked ) return;
+    }
+
+    QMenu *contextMenu = new QMenu(this);
+    contextMenu->addAction(ic1, tr("Copy"), this, SLOT(addToClipboard()));
+
+    if ( (multi==0) || (multi==1 && seleccionados==1 && ui->listWidget->currentItem()->checkState()==Qt::Checked ) )
+        contextMenu->addAction(ic1, tr("Rename"), this, SLOT(renameSel()));
+
+    contextMenu->addAction(ic1, tr("Delete"), this, SLOT(removeSel()));
+
+    if ( ( multi==1 && seleccionados==1 && ui->listWidget->currentItem()->checkState()==Qt::Checked && QFileInfo(item).isFile() ) || ( multi==0 && QFileInfo(item).isFile() ) )
+    {
+        contextMenu->addAction(ic1, tr("Edit"), this, SLOT(editSel()));
+    }
+
+    if ( ( multi==1 && seleccionados==1 && ui->listWidget->currentItem()->checkState()==Qt::Checked && QFileInfo(item).isDir() ) ||  ( multi==0 && QFileInfo(item).isDir() ) )
+    {
+        contextMenu->addSeparator();
+        contextMenu->addAction(ic1, tr("Change icon"), this, SLOT(changeIcon()));
+    }
+    contextMenu->addAction(ic1, tr("Compress"), this, SLOT(compressSel()));
+
+    if ( ( multi==1 && seleccionados>0 ) ||  ( multi==0 && QFileInfo(item).isFile() ) )
+    {
+        contextMenu->addSeparator();
+        contextMenu->addAction(ic1, tr("Share"), this, SLOT(shareBT()));
+    }
+
+    /*if ( (multi==0) || (multi==1 && ui->listWidget->selectedItems().count()==1) )
+    {
+        contextMenu->addSeparator();
+        contextMenu->addAction(ic1, tr("Permissions"), this, SLOT(permissionSel()));
+    }*/
+
+
     contextMenu->exec(mapToGlobal(pos));
+
 }
 
 void MainWindow::changeIcon()
@@ -1532,54 +1574,3 @@ void MainWindow::on_h_full_clicked()
     else
         this->setWindowState(Qt::WindowFullScreen);
 }
-
-void MainWindow::on_listWidget_itemSelectionChanged()
-{
-
-    int seleccionados=0;
-    QString item = sPath + "/" + ui->listWidget->currentItem()->statusTip();
-
-    if ( multi == 1 )
-    {
-        for (int mi=0; mi < ui->listWidget->count(); ++mi)
-        {
-            if ( ui->listWidget->item(mi)->checkState()==Qt::Checked ) seleccionados=seleccionados+1;
-        }
-        if (seleccionados==0) return;
-        if (seleccionados>=1 && ui->listWidget->currentItem()->checkState()==Qt::Unchecked ) return;
-    }
-
-    contextMenu = new QMenu(this);
-    contextMenu->addAction(ic1, tr("Copy"), this, SLOT(addToClipboard()));
-
-    if ( (multi==0) || (multi==1 && seleccionados==1 && ui->listWidget->currentItem()->checkState()==Qt::Checked ) )
-        contextMenu->addAction(ic1, tr("Rename"), this, SLOT(renameSel()));
-
-    contextMenu->addAction(ic1, tr("Delete"), this, SLOT(removeSel()));
-
-    if ( ( multi==1 && seleccionados==1 && ui->listWidget->currentItem()->checkState()==Qt::Checked && QFileInfo(item).isFile() ) || ( multi==0 && QFileInfo(item).isFile() ) )
-    {
-        contextMenu->addAction(ic1, tr("Edit"), this, SLOT(editSel()));
-    }
-
-    if ( ( multi==1 && seleccionados==1 && ui->listWidget->currentItem()->checkState()==Qt::Checked && QFileInfo(item).isDir() ) ||  ( multi==0 && QFileInfo(item).isDir() ) )
-    {
-        contextMenu->addSeparator();
-        contextMenu->addAction(ic1, tr("Change icon"), this, SLOT(changeIcon()));
-    }
-    contextMenu->addAction(ic1, tr("Compress"), this, SLOT(compressSel()));
-
-    if ( ( multi==1 && seleccionados>0 ) ||  ( multi==0 && QFileInfo(item).isFile() ) )
-    {
-        contextMenu->addSeparator();
-        contextMenu->addAction(ic1, tr("Share"), this, SLOT(shareBT()));
-    }
-
-    /*if ( (multi==0) || (multi==1 && ui->listWidget->selectedItems().count()==1) )
-    {
-        contextMenu->addSeparator();
-        contextMenu->addAction(ic1, tr("Permissions"), this, SLOT(permissionSel()));
-    }*/
-
-
-}
